'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.createPolyglotMiddleware = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _actions = require('./actions');

// eslint-disable-next-line valid-typeof
var is = function is(type) {
    return function (x) {
        return (typeof x === 'undefined' ? 'undefined' : _typeof(x)) === type;
    };
};

var isString = is('string');
var isFunction = is('function');
var isArray = Array.isArray;

var checkParams = function checkParams(catchedAction, getLocale, getPhrases) {
    if (!catchedAction || !getLocale || !getPhrases) throw new Error('polyglotMiddleware : missing parameters.');
    if (!isString(catchedAction) && !isArray(catchedAction)) {
        throw new Error('polyglotMiddleware : first parameter must be a string or an array of string.');
    }
    if (!isFunction(getLocale)) throw new Error('polyglotMiddleware : second parameter must be a function.');
    if (!isFunction(getPhrases)) throw new Error('polyglotMiddleware : third parameter must be a function.');
};

var createPolyglotMiddleware = exports.createPolyglotMiddleware = function createPolyglotMiddleware(catchedAction, getLocale, getPhrases) {
    checkParams(catchedAction, getLocale, getPhrases);
    var actions = isArray(catchedAction) ? catchedAction : [catchedAction];
    return function (_ref) {
        var dispatch = _ref.dispatch;
        return function (next) {
            return function (action) {
                if (actions.includes(action.type)) {
                    (function () {
                        var locale = getLocale(action);
                        getPhrases(locale).then(function (phrases) {
                            dispatch((0, _actions.setLanguage)(locale, phrases));
                        });
                    })();
                }
                return next(action);
            };
        };
    };
};